@@ -12,14 +12,14 @@ def run():
     args = workbench_client.grab_server_args()
 
     # Start up workbench connection
-    workbench = zerorpc.Client(timeout=120)
+    workbench = zerorpc.Client(timeout=300, heartbeat=60)
     workbench.connect('tcp://'+args['server']+':'+args['port'])
 
     # Test out PEFile -> peid
     data_path = os.path.join(os.path.dirname(os.path.realpath(__file__)),'../data/pe/bad')
-    file_list = [os.path.join(data_path, child) for child in os.listdir(data_path)][:10]
+    file_list = [os.path.join(data_path, child) for child in os.listdir(data_path)][:3]
     data_path = os.path.join(os.path.dirname(os.path.realpath(__file__)),'../data/pe/good')
-    file_list += [os.path.join(data_path, child) for child in os.listdir(data_path)][:10]
+    file_list += [os.path.join(data_path, child) for child in os.listdir(data_path)][:3]
     for filename in file_list:
 
         # Skip OS generated files
