@@ -12,7 +12,7 @@ def run():
     args = workbench_client.grab_server_args()
 
     # Start up workbench connection
-    workbench = zerorpc.Client(timeout=120)
+    workbench = zerorpc.Client(timeout=300, heartbeat=60)
     workbench.connect('tcp://'+args['server']+':'+args['port'])
 
     # Test out zip data
@@ -32,8 +32,6 @@ def run():
             for child_md5 in results['unzip']['payload_md5s']:
                 pprint.pprint(workbench.work_request('meta', child_md5))
 
-import pytest
-@pytest.mark.xfail
 def test():
     """Executes simple_workbench_client test."""
     run()
