@@ -1,6 +1,6 @@
 """DataStore class for WorkBench."""
 
-from gevent import monkey
+from gevent import monkey; monkey.patch_socket()
 import pymongo
 import gridfs
 import hashlib
@@ -8,7 +8,7 @@ import datetime
 import bson
 import time
 
-monkey.patch_socket()
+
 
 class DataStore(object):
     """DataStore for Workbench. 
@@ -273,6 +273,8 @@ class DataStore(object):
             md5: the md5 of sample data to be updated.
 
         """
+
+        # Make sure the md5 and time stamp is on the data before storing
         results['md5'] = md5
         results['__time_stamp'] = datetime.datetime.utcnow()
 
