@@ -4,7 +4,7 @@
 from gevent import monkey; monkey.patch_all(thread=False) # Monkey!
 from gevent import signal as gevent_signal
 import signal
-import os
+import sys, os
 import zerorpc
 import zmq
 import logging
@@ -17,11 +17,21 @@ import funcsigs
 import ConfigParser
 
 # Workbench server imports
-from . import data_store
-from . import els_indexer
-from . import neo_db
-from . import plugin_manager
-from bro import bro_log_reader
+try:
+    from . import data_store
+    from . import els_indexer
+    from . import neo_db
+    from . import plugin_manager
+    from bro import bro_log_reader
+
+# Okay this happens when you're running workbench in a debugger so having
+# this is super handy and we'll keep it even though it hurts coverage score.
+except ValueError:
+    import data_store
+    import els_indexer
+    import neo_db
+    import plugin_manager
+    from bro import bro_log_reader
 
 
 class WorkBench(object):
@@ -34,6 +44,12 @@ class WorkBench(object):
             els_hosts: The address where Elastic Search Indexer is running.
             neo_uri: The address where Neo4j is running.
         """
+        # Announce Version
+        try:
+            print '<<< Workbench Version %s >>>' % sys.modules['workbench'].__version__
+        except KeyError:
+            print '<<< Workbench Version %s >>>' % 'DEBUGGING'
+
         # Open DataStore
         self.data_store = data_store.DataStore(**store_args)
 
@@ -386,10 +402,11 @@ class WorkBench(object):
 
         # Looking for the sample or sample_set?
         if (worker_class == 'sample'):
-            try:
-                return self.get_sample(md5)
-            except RuntimeError:
+            # If we have a sample set with this md5, return it
+            if self.get_sample_set(md5):
                 return self.get_sample_set(md5)
+            # Return the sample (might raise a RuntimeError)
+            return self.get_sample(md5)
 
         # Do I actually have this plugin? (might have failed, etc)
         if (worker_class not in self.plugin_meta):
@@ -406,6 +423,7 @@ class WorkBench(object):
             else:
                 print 'Updating work results for new plugin: %s' % (worker_class)
 
+        # Okay either need to generate (or re-generate) the work results
         dependencies = self.plugin_meta[worker_class]['dependencies']
         dependant_results = {}
         for dependency in dependencies:
@@ -413,6 +431,11 @@ class WorkBench(object):
         print 'New work for plugin: %s' % (worker_class)
         work_results = self.plugin_meta[worker_class]['class']().execute(dependant_results)
 
+        # Enforce dictionary output
+        if not isinstance(work_results, dict):
+            print 'Critical: Plugin %s MUST produce a python dictionary!' % worker_class
+            return None
+
         # Store the results and return
         self._store_work_results(work_results, collection, md5)
         return self._get_work_results(collection, md5)
@@ -430,7 +453,7 @@ class WorkBench(object):
         help_str += '\n\t - Run workbench.help_commands() for command help'
         help_str += '\n\t - Run workbench.help_workers() for a list of workers'
         help_str += '\n\t - Run workbench.help_advanced() for advanced help'
-        help_str += '\n\nSee https://github.com/SuperCowPowers/workbench for more information'
+        help_str += '\n\nSee http://github.com/SuperCowPowers/workbench for more information'
         return help_str
 
     def help_basic(self):
@@ -459,6 +482,12 @@ class WorkBench(object):
                 return '\n Command: %s%s \n%s' % (name, funcsigs.signature(meth), meth.__doc__)
         return '%s command not found.. misspelled?' % command
 
+    def list_all_commands(self):
+        """ Returns a list of all the Workbench commands"""
+        commands = [name for name, _ in inspect.getmembers(self, predicate=inspect.ismethod) if not name.startswith('_')]
+        commands.append('batch_work_request') # I think the zerorpc decorator messes up inspect
+        return commands
+
     def help_workers(self):
         """ Returns a big string of the loaded Workbench workers and their dependencies """
         help_string = 'Workbench Workers:'
@@ -477,7 +506,7 @@ class WorkBench(object):
     def help_advanced(self):
         """ Returns advanced help commands """
         help_str =  '\nWoo! Advanced... <fixme: add documentation for advanced> :)'
-        help_str += '\n\nSee https://github.com/SuperCowPowers/workbench for more information'
+        help_str += '\n\nSee http://github.com/SuperCowPowers/workbench for more information'
         return help_str
 
     def list_all_workers(self):
@@ -522,15 +551,16 @@ def run():
     # Spin up Workbench ZeroRPC
     try:
         store_args = {'uri': datastore_uri, 'database': database, 'worker_cap':worker_cap, 'samples_cap':samples_cap}
-        workbench = zerorpc.Server(WorkBench(store_args=store_args), name='workbench')
+        workbench = zerorpc.Server(WorkBench(store_args=store_args), name='workbench', heartbeat=60)
         workbench.bind('tcp://0.0.0.0:4242')
         print 'ZeroRPC %s' % ('tcp://0.0.0.0:4242')
         gevent_signal(signal.SIGTERM, workbench.stop)
         gevent_signal(signal.SIGINT, workbench.stop)
         gevent_signal(signal.SIGKILL, workbench.stop)
         workbench.run()
-        print '\nWorkbench Server Shutting Down...'
-        exit(0)        
+        print '\nWorkbench Server Shutting Down... and dreaming of sheep...'
+        import time
+        time.sleep(1)
     except zmq.error.ZMQError:
         print '\nInfo: Could not start Workbench server (no worries, probably already running...)\n'
 
