@@ -1,6 +1,6 @@
 
 ''' Memory Image base worker. This worker utilizes the Rekall Memory Forensic Framework.
-    See Google Github: https://github.com/google/rekall
+    See Google Github: http://github.com/google/rekall
     All credit for good stuff goes to them, all credit for bad stuff goes to us. :)
 '''
 
@@ -44,14 +44,12 @@ class MemoryImageBase(object):
 
 
 # Unit test: Create the class, the proper input and run the execute() method for a test
-import pytest
-@pytest.mark.rekall
 def test():
     ''' mem_base.py: Test '''
 
     # This worker test requires a local server running
     import zerorpc
-    c = zerorpc.Client(timeout=120)
+    c = zerorpc.Client(timeout=300, heartbeat=60)
     c.connect("tcp://127.0.0.1:4242")
 
     # Do we have the memory forensics file?
@@ -59,12 +57,12 @@ def test():
     if not os.path.isfile(data_path):
         print 'Not finding exemplar4.mem... Downloading now...'
         import urllib
-        urllib.urlretrieve('https://s3-us-west-2.amazonaws.com/workbench-data/memory_images/exemplar4.vmem', data_path)
+        urllib.urlretrieve('http://s3-us-west-2.amazonaws.com/workbench-data/memory_images/exemplar4.vmem', data_path)
 
     # Did we properly download the memory file?
     if not os.path.isfile(data_path):
         print 'Downloading failed, try it manually...'
-        print 'wget https://s3-us-west-2.amazonaws.com/workbench-data/memory_images/exemplar4.vmem'
+        print 'wget http://s3-us-west-2.amazonaws.com/workbench-data/memory_images/exemplar4.vmem'
         exit(1)
 
     # Store the sample
