@@ -1,6 +1,6 @@
 
 ''' Memory Image ProcDump worker. This worker utilizes the Rekall Memory Forensic Framework.
-    See Google Github: https://github.com/google/rekall
+    See Google Github: http://github.com/google/rekall
     All credit for good stuff goes to them, all credit for bad stuff goes to us. :)
 '''
 
@@ -10,6 +10,7 @@ import contextlib
 import tempfile
 import shutil
 import glob, os
+import hashlib
 
 class MemoryImageProcDump(object):
     ''' This worker dumps process pe files from memory image files. '''
@@ -22,7 +23,7 @@ class MemoryImageProcDump(object):
         self.orig_dir = os.getcwd()
 
         # Spin up workbench connection
-        self.c = zerorpc.Client(timeout=120)
+        self.c = zerorpc.Client(timeout=300, heartbeat=60)
         self.c.connect("tcp://127.0.0.1:4242")        
 
     def execute(self, input_data):
@@ -60,9 +61,18 @@ class MemoryImageProcDump(object):
                 output_name = output_name.replace('executable.', '')
                 with open(output_file, 'rb') as dumped_file:
                     raw_bytes = dumped_file.read()
-                    self.output['dumped_files'].append({'name': output_name, 
-                                'md5':self.c.store_sample(output_name, raw_bytes, 'pe')})
+                    md5 = self.c.store_sample(output_name, raw_bytes, 'pe')
 
+                    # Remove some columns from meta data
+                    meta = self.c.work_request('meta', md5)['meta']
+                    del meta['customer']
+                    del meta['encoding']
+                    del meta['import_time']
+                    del meta['mime_type']
+                    self.output['dumped_files'].append(meta)
+
+        # Organize the output a bit
+        self.output['tables'] = ['dumped_files']
         return self.output
 
     @contextlib.contextmanager
@@ -92,26 +102,27 @@ def test():
 
     # This worker test requires a local server running
     import zerorpc
-    c = zerorpc.Client(timeout=120)
-    c.connect("tcp://127.0.0.1:4242")
+    workbench = zerorpc.Client(timeout=300, heartbeat=60)
+    workbench.connect("tcp://127.0.0.1:4242")
 
     # Store the sample
     data_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), '../data/memory_images/exemplar4.vmem')
-    md5 = c.store_sample('exemplar4.vmem', open(data_path, 'rb').read(), 'mem')
-
-    # Unit test stuff
-    input_data = c.get_sample(md5)
+    with open(data_path, 'rb') as mem_file:
+        raw_bytes = mem_file.read()
+        md5 = hashlib.md5(raw_bytes).hexdigest()
+        if not workbench.has_sample(md5):
+            md5 = workbench.store_sample('exemplar4.vmem', open(data_path, 'rb').read(), 'mem')
 
     # Execute the worker (unit test)
     worker = MemoryImageProcDump()
-    output = worker.execute(input_data)
+    output = worker.execute({'sample':{'raw_bytes':raw_bytes}})
     print '\n<<< Unit Test >>>'
     import pprint
     pprint.pprint(output)
     assert 'Error' not in output
 
     # Execute the worker (server test)
-    output = c.work_request('mem_procdump', md5)
+    output = workbench.work_request('mem_procdump', md5)
     print '\n<<< Server Test >>>'
     import pprint
     pprint.pprint(output)
