@@ -9,7 +9,7 @@ class PcapGraph(object):
 
     def __init__(self):
         ''' Initialization '''
-        self.workbench = zerorpc.Client(timeout=120)
+        self.workbench = zerorpc.Client(timeout=300, heartbeat=60)
         self.workbench.connect('tcp://127.0.0.1:4242')
         self.mime_types = ['application/x-dosexec', 'application/pdf', 'application/zip',
                            'application/jar', 'application/vnd.ms-cab-compressed',
@@ -209,7 +209,7 @@ def test():
     ''' pcap_graph.py: Unit test '''
     # This worker test requires a local server as it relies on the recursive dependencies
     import zerorpc
-    workbench = zerorpc.Client(timeout=300)
+    workbench = zerorpc.Client(timeout=300, heartbeat=60)
     workbench.connect("tcp://127.0.0.1:4242")
 
     # Generate the input data for this worker
