@@ -328,7 +328,7 @@ def test():
 
     # This worker test requires a local server running
     import zerorpc
-    workbench = zerorpc.Client(timeout=120)
+    workbench = zerorpc.Client(timeout=300, heartbeat=60)
     workbench.connect('tcp://127.0.0.1:4242')
 
     # Generate 3 different inputs for the worker (better coverage)
