@@ -43,7 +43,7 @@ def test():
 
     # This worker test requires a local server running
     import zerorpc
-    workbench = zerorpc.Client(timeout=120)
+    workbench = zerorpc.Client(timeout=300, heartbeat=60)
     workbench.connect("tcp://127.0.0.1:4242")
 
     # Generate input for the worker
@@ -52,7 +52,6 @@ def test():
                              '../data/pe/bad/033d91aae8ad29ed9fbb858179271232')
     md5 = workbench.store_sample('bad', open(data_path, 'rb').read(), 'pe')
     input_data = workbench.get_sample(md5)
-    input_data.update(workbench.work_request('meta', md5))
 
     # Execute the worker (unit test)
     worker = PEIDWorker()
