@@ -1,9 +1,10 @@
 
 """rekall_adapter: Helps Workbench utilize the Rekall Memory Forensic Framework.
-    See Google Github: https://github.com/google/rekall
+    See Google Github: http://github.com/google/rekall
     All credit for good stuff goes to them, all credit for bad stuff goes to us. :).
 """
 
+
 import os
 import logging
 from rekall import plugins
@@ -17,6 +18,10 @@ import datetime
 import pprint
 import msgpack
 import pytz
+import gevent
+def gsleep():
+    print '*** Gevent Sleep ***'
+    gevent.sleep(0)
 
 class RekallAdapter(object):
     """RekallAdapter: Helps utilize the Rekall Memory Forensic Framework."""
@@ -24,9 +29,13 @@ class RekallAdapter(object):
     def __init__(self, raw_bytes):
         """Initialization."""
 
+        gsleep()
         self.MemS = MemSession(raw_bytes)
+        gsleep()
         self.renderer = WorkbenchRenderer()
+        gsleep()
         self.session = self.MemS.get_session()
+        gsleep()
 
     def get_session(self):
         return self.session
@@ -204,8 +213,6 @@ class WorkbenchRenderer(BaseRenderer):
 
 
 # Unit test: Create the class, the proper input and run the execute() method for a test
-import pytest
-@pytest.mark.rekall
 def test():
     """rekall_adapter.py: Test."""
 
@@ -214,7 +221,7 @@ def test():
     if not os.path.isfile(data_path):
         print 'Not finding exemplar4.mem... Downloading now...'
         import urllib
-        urllib.urlretrieve('https://s3-us-west-2.amazonaws.com/workbench-data/memory_images/exemplar4.vmem', data_path)
+        urllib.urlretrieve('http://s3-us-west-2.amazonaws.com/workbench-data/memory_images/exemplar4.vmem', data_path)
 
     # Did we properly download the memory file?
     if not os.path.isfile(data_path):
