@@ -18,7 +18,7 @@ def test():
 
     # This worker test requires a local server running
     import zerorpc
-    workbench = zerorpc.Client(timeout=120)
+    workbench = zerorpc.Client(timeout=300, heartbeat=60)
     workbench.connect("tcp://127.0.0.1:4242")
 
     # Generate input for the worker
@@ -26,8 +26,7 @@ def test():
     data_path = os.path.join(os.path.dirname(os.path.realpath(__file__)),
                              '../data/pe/bad/033d91aae8ad29ed9fbb858179271232')
     md5 = workbench.store_sample('bad_pe', open(data_path, 'rb').read(), 'pe')
-    input_data = workbench.get_sample(md5)
-    input_data.update(workbench.work_request('meta', md5))
+    input_data = workbench.work_request('meta', md5)
 
     # Execute the worker (unit test)
     worker = ViewCustomer()
