@@ -7,7 +7,7 @@ class ViewPcap(object):
     dependencies = ['pcap_bro']
 
     def __init__(self):
-        self.workbench = zerorpc.Client(timeout=120)
+        self.workbench = zerorpc.Client(timeout=300, heartbeat=60)
         self.workbench.connect("tcp://127.0.0.1:4242")
 
     def execute(self, input_data):
@@ -33,7 +33,7 @@ def test():
 
     # This worker test requires a local server running
     import zerorpc
-    workbench = zerorpc.Client(timeout=120)
+    workbench = zerorpc.Client(timeout=300, heartbeat=60)
     workbench.connect("tcp://127.0.0.1:4242")
 
     # Generate input for the worker
@@ -41,8 +41,7 @@ def test():
     data_path = os.path.join(os.path.dirname(os.path.realpath(__file__)),
                              '../data/pcap/winmediaplayer.pcap')
     md5 = workbench.store_sample('winmedia.pcap', open(data_path, 'rb').read(), 'pcap')
-    input_data = workbench.get_sample(md5)
-    input_data.update(workbench.work_request('pcap_bro', md5))
+    input_data = workbench.work_request('pcap_bro', md5)
 
     # Execute the worker (unit test)
     worker = ViewPcap()
