@@ -9,7 +9,7 @@ class ViewPcapDetails(object):
 
     def __init__(self):
         ''' Initialization of ViewPcapDetails '''
-        self.workbench = zerorpc.Client(timeout=120)
+        self.workbench = zerorpc.Client(timeout=300, heartbeat=60)
         self.workbench.connect("tcp://127.0.0.1:4242")
 
     def execute(self, input_data):
@@ -42,7 +42,7 @@ def test():
 
     # This worker test requires a local server running
     import zerorpc
-    workbench = zerorpc.Client(timeout=120)
+    workbench = zerorpc.Client(timeout=300, heartbeat=60)
     workbench.connect("tcp://127.0.0.1:4242")
 
     # Generate input for the worker
@@ -50,8 +50,7 @@ def test():
     data_path = os.path.join(os.path.dirname(os.path.realpath(__file__)),
                              '../data/pcap/winmediaplayer.pcap')
     md5 = workbench.store_sample('winmedia.pcap', open(data_path, 'rb').read(), 'pcap')
-    input_data = workbench.get_sample(md5)
-    input_data.update(workbench.work_request('view_pcap', md5))
+    input_data = workbench.work_request('view_pcap', md5)
 
     # Execute the worker (unit test)
     worker = ViewPcapDetails()
