@@ -9,7 +9,7 @@ class ViewZip(object):
     dependencies = ['meta', 'unzip']
 
     def __init__(self):
-        self.workbench = zerorpc.Client(timeout=120)
+        self.workbench = zerorpc.Client(timeout=300, heartbeat=60)
         self.workbench.connect("tcp://127.0.0.1:4242")
 
     def execute(self, input_data):
@@ -37,14 +37,13 @@ def test():
     ''' -- view_zip.py test -- '''
 
     # This worker test requires a local server running
-    workbench = zerorpc.Client(timeout=120)
+    workbench = zerorpc.Client(timeout=300, heartbeat=60)
     workbench.connect("tcp://127.0.0.1:4242")
 
     # Generate input for the worker
     data_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), '../data/zip/bad.zip')
     md5 = workbench.store_sample('bad.zip', open(data_path, 'rb').read(), 'zip')
-    input_data = workbench.get_sample(md5)
-    input_data.update(workbench.work_request('meta', md5))
+    input_data = workbench.work_request('meta', md5)
     input_data.update(workbench.work_request('unzip', md5))
 
     # Execute the worker (unit test)
